@@ -1,5 +1,4 @@
-#!/usr/local/bin/python2.3
-
+#!/usr/local/bin/python2.4
 ##############################################################################
 #
 # Copyright (c) 2001 Zope Corporation and Contributors. All Rights Reserved.
@@ -12,11 +11,10 @@
 # FOR A PARTICULAR PURPOSE
 #
 ##############################################################################
+"""Request log profiler script
 
-""" Request log profiler script """
-
-__version__='$Revision: 1.17.66.2 $'[11:-2]
-
+$Id: requestprofiler.py 24764 2004-05-17 06:13:48Z philikon $
+"""
 import sys, time, getopt, math, cPickle
 from types import StringType
 try: import gzip
