@@ -36,13 +36,14 @@
 
    ACCESS_NONE:    no access
 
-$Id$
 """
 
 import sys
+
 import Acquisition
-from zLOG import LOG, WARNING
+
 from AccessControl.ImplPython import _what_not_even_god_should_do
+from zLOG import LOG, WARNING
 
 
 # Security constants - these are imported into the AccessControl
@@ -125,7 +126,7 @@ class SecurityInfo(Acquisition.Implicit):
         This should be a boolean value, a map of attribute names to
         booleans, or a callable (name, value) -> boolean.
         """
-        if type(access) == type(''):
+        if isinstance(access, str):
             access = access.lower()
             if access == 'allow':
                 access = 1
@@ -162,7 +163,7 @@ class ClassSecurityInfo(SecurityInfo):
         ac_permissions = {}
         for name, access in self.names.items():
             if access in (ACCESS_PRIVATE, ACCESS_PUBLIC, ACCESS_NONE):
-                dict['%s__roles__' % name] = access
+                setattr(classobj, '%s__roles__' % name, access)
             else:
                 if not ac_permissions.has_key(access):
                     ac_permissions[access] = []
@@ -182,12 +183,13 @@ class ClassSecurityInfo(SecurityInfo):
             else:
                 entry = (permission_name, tuple(names))
             __ac_permissions__.append(entry)
-        dict['__ac_permissions__'] = tuple(__ac_permissions__)
+        setattr(classobj, '__ac_permissions__', tuple(__ac_permissions__))
 
         # Take care of default attribute access policy
         access = getattr(self, 'access', _marker)
         if access is not _marker:
-            dict['__allow_access_to_unprotected_subobjects__'] = access
+            setattr(classobj, '__allow_access_to_unprotected_subobjects__',
+                    access)
 
         if getattr(self, '_warnings', None):
             LOG('SecurityInfo', WARNING, 'Class "%s" had conflicting '
