@@ -12,7 +12,7 @@
 ##############################################################################
 __doc__="""System management components"""
 
-__version__='$Revision: 1.88.4.5 $'[11:-2]
+__version__='$Revision: 1.94 $'[11:-2]
 
 import sys,os,time,Globals, Acquisition, os, Undo
 from Globals import DTMLFile
@@ -376,11 +376,9 @@ class ApplicationManager(Folder,CacheManager):
         return self._p_jar.db().getName()
 
     def db_size(self):
-        if Globals.DatabaseVersion=='2':
-            s=os.stat(self.db_name())[6]
-        else:
-            s=self._p_jar.db().getSize()
-            if type(s) is type(''): return s
+        s=self._p_jar.db().getSize()
+        if type(s) is type(''):
+            return s
 
         if s >= 1048576.0: return '%.1fM' % (s/1048576.0)
         return '%.1fK' % (s/1024.0)
@@ -536,7 +534,7 @@ class ApplicationManager(Folder,CacheManager):
 class AltDatabaseManager(DatabaseManager, CacheManager):
     """Database management DBTab-style
     """
-    db_name = ApplicationManager.db_name
-    db_size = ApplicationManager.db_size
-    manage_pack = ApplicationManager.manage_pack
+    db_name = ApplicationManager.db_name.im_func
+    db_size = ApplicationManager.db_size.im_func
+    manage_pack = ApplicationManager.manage_pack.im_func
 
