@@ -12,32 +12,13 @@
 ##############################################################################
 """Encapsulation of date/time values"""
 
-__version__='$Revision: 1.85.12.13 $'[11:-2]
+__version__='$Revision: 1.99 $'[11:-2]
 
 
 import re, math,  DateTimeZone
-from time import time, gmtime, localtime 
+from time import time, gmtime, localtime
 from time import daylight, timezone, altzone, strftime
-
-
-try:
-    from time import tzname
-except:
-    tzname=('UNKNOWN','UNKNOWN')
-
-class DateTimeError( Exception ):
-    pass
-
-class SyntaxError( DateTimeError ):
-    pass
-
-class DateError( DateTimeError ):
-    pass
-
-class TimeError( DateTimeError ):
-    pass
-
-from App.config import getConfiguration
+from datetime import datetime
 
 default_datefmt = None
 
@@ -45,6 +26,7 @@ def getDefaultDateFormat():
     global default_datefmt
     if default_datefmt is None:
         try:
+            from App.config import getConfiguration
             default_datefmt = getConfiguration().datetime_format
             return default_datefmt
         except:
@@ -71,7 +53,6 @@ class TimeError( DateTimeError ):
     pass
 
 
-
 # To control rounding errors, we round system time to the nearest
 # millisecond.  Then delicate calculations can rely on that the
 # maximum precision that needs to be preserved is known.
@@ -464,9 +445,9 @@ def _tzoffset2rfc822zone(seconds):
 
 def _tzoffset2iso8601zone(seconds):
     """Takes an offset, such as from _tzoffset(), and returns an ISO 8601
-       compliant zone specification. Please note that the result of 
+       compliant zone specification. Please note that the result of
        _tzoffset() is the negative of what time.localzone and time.altzone is."""
-    return "%+03d:%02d" % divmod( (seconds/60), 60) 
+    return "%+03d:%02d" % divmod( (seconds/60), 60)
 
 
 class DateTime:
@@ -531,7 +512,8 @@ class DateTime:
         except:
             raise SyntaxError('Unable to parse %s, %s' % (args, kw))
 
-    def _parse_args(self,*args, **kw):
+
+    def _parse_args(self, *args, **kw):
         """Return a new date-time object
 
         A DateTime object always maintains its value as an absolute
@@ -628,6 +610,10 @@ class DateTime:
             the gmt value of the time.time() float represented in
             the local machine's timezone.
 
+          - If the DateTime function is invoked with a single
+            argument that is a DateTime instane, a copy of the 
+            passed object will be created.
+
           - If the function is invoked with two numeric arguments,
             then the first is taken to be an integer year and the
             second argument is taken to be an offset in days from
@@ -750,6 +736,7 @@ class DateTime:
                 else:
                     yr,mo,dy,hr,mn,sc,tz=self._parse(arg, datefmt)
 
+
                 if not self._validDate(yr,mo,dy):
                     raise DateError, 'Invalid date: %s' % arg
                 if not self._validTime(hr,mn,int(sc)):
@@ -1494,8 +1481,27 @@ class DateTime:
         return millis
 
     def strftime(self, format):
-        # Format the date/time using the *local timezone representation*.
-        return strftime(format, safelocaltime(self.timeTime()))
+        # Format the date/time using the *current timezone representation*.
+        x      = _calcDependentSecond2(self._year, self._month, self._day, 
+                 self._hour, self._minute, self._second)
+        ltz    = self._calcTimezoneName(x, 0)
+        tzdiff = _tzoffset(ltz, self._t) - _tzoffset(self._tz, self._t)
+        zself  = self + tzdiff/86400.0
+        microseconds = int((zself._second - zself._nearsec) * 1000000)
+
+        # Note: in older versions strftime() accepted also unicode strings
+        # as format strings (just because time.strftime() did not perform
+        # any type checking). So we convert unicode strings to utf8,
+        # pass them to strftime and convert them back to unicode if necessary.
+
+        format_is_unicode = False
+        if isinstance(format, unicode):
+            format = format.encode('utf-8')
+            format_is_unicode = True
+        ds = datetime(zself._year, zself._month, zself._day, zself._hour,  
+               zself._minute, int(zself._nearsec), 
+               microseconds).strftime(format) 
+        return format_is_unicode and unicode(ds, 'utf-8') or ds
 
     # General formats from previous DateTime
     def Date(self):
@@ -1605,7 +1611,7 @@ class DateTime:
 
     def ISO8601(self):
         """Return the object in ISO 8601-compatible format containing
-        the date, time with seconds-precision and the time zone 
+        the date, time with seconds-precision and the time zone
         identifier - see http://www.w3.org/TR/NOTE-datetime
 
         Dates are output as: YYYY-MM-DDTHH:MM:SSTZD
