@@ -10,43 +10,46 @@
 # FOR A PARTICULAR PURPOSE
 #
 ##############################################################################
-__doc__="""Object Manager
+"""Object Manager
 
-$Id: ObjectManager.py,v 1.163.12.11 2004/06/25 09:28:09 ctheune Exp $"""
+$Id: ObjectManager.py 38738 2005-10-04 11:02:52Z efge $
+"""
 
-__version__='$Revision: 1.163.12.11 $'[11:-2]
+import sys, fnmatch, copy, os, re
+import marshal
+from cgi import escape
+from cStringIO import StringIO
+from types import StringType, UnicodeType
 
-import App.Management, Acquisition, Globals, CopySupport, Products
-import os, App.FactoryDispatcher, re, Products
-from OFS.Traversable import Traversable
-from OFS import SimpleItem
+import App.Management, Acquisition, Globals, Products
+import App.FactoryDispatcher, Products
 from Globals import DTMLFile, Persistent
 from Globals import MessageDialog, default__class_init__
 from Globals import REPLACEABLE, NOT_REPLACEABLE, UNIQUE
 from webdav.NullResource import NullResource
 from webdav.Collection import Collection
 from Acquisition import aq_base
-from AccessControl.SecurityInfo import ClassSecurityInfo
 from webdav.Lockable import ResourceLockedError
 from ZODB.POSException import ConflictError
-from urllib import quote
-from cStringIO import StringIO
-import marshal
 import App.Common
 from App.config import getConfiguration
 from AccessControl import getSecurityManager
+from AccessControl.ZopeSecurityPolicy import getRoles
 from zLOG import LOG, ERROR
 from zExceptions import BadRequest
-import sys,fnmatch,copy
-from cgi import escape
-from types import StringType, UnicodeType
+
+from OFS.Traversable import Traversable
+import CopySupport
+
+# the name BadRequestException is relied upon by 3rd-party code
+BadRequestException = BadRequest
 
 import XMLExportImport
 customImporters={
     XMLExportImport.magic: XMLExportImport.importXML,
     }
 
-bad_id=re.compile(r'[^a-zA-Z0-9-_~,.$\(\)# ]').search #TS
+bad_id=re.compile(r'[^a-zA-Z0-9-_~,.$\(\)# @]').search
 
 def checkValidId(self, id, allow_dup=0):
     # If allow_dup is false, an error will be raised if an object
@@ -90,11 +93,20 @@ def checkValidId(self, id, allow_dup=0):
         raise BadRequest, (
             'The id "%s" contains characters illegal in URLs.' % id)
 
-class BeforeDeleteException(Exception): pass # raise to veto deletion
-class BreakoutException(Exception): pass  # raised to break out of loops
-BadRequestException = BadRequest
+
+class BeforeDeleteException(Exception):
+
+    pass # raise to veto deletion
+
+
+class BreakoutException(Exception):
+
+    pass  # raised to break out of loops
+
 
 _marker=[]
+
+
 class ObjectManager(
     CopySupport.CopyContainer,
     App.Management.Navigation,
@@ -104,13 +116,14 @@ class ObjectManager(
     Collection,
     Traversable,
     ):
+
     """Generic object manager
 
     This class provides core behavior for collections of heterogeneous objects.
     """
 
     __ac_permissions__=(
-        ('View management screens', ('manage_main','manage_menu')),
+        ('View management screens', ('manage_main',)),
         ('Access contents information',
          ('objectIds', 'objectValues', 'objectItems',''),
          ('Anonymous', 'Manager'),
@@ -124,11 +137,11 @@ class ObjectManager(
     )
 
 
-    meta_type  ='Object Manager'
+    meta_type = 'Object Manager'
 
     meta_types=() # Sub-object types that are specific to this object
 
-    _objects   =()
+    _objects = ()
 
     manage_main=DTMLFile('dtml/main', globals())
     manage_index_main=DTMLFile('dtml/index_main', globals())
@@ -231,8 +244,12 @@ class ObjectManager(
 
     _checkId = checkValidId
 
-    def _setOb(self, id, object): setattr(self, id, object)
-    def _delOb(self, id): delattr(self, id)
+    def _setOb(self, id, object):
+        setattr(self, id, object)
+
+    def _delOb(self, id):
+        delattr(self, id)
+
     def _getOb(self, id, default=_marker):
         # FIXME: what we really need to do here is ensure that only
         # sub-items are returned. That could have a measurable hit
@@ -244,7 +261,7 @@ class ObjectManager(
             raise AttributeError, id
         return default
 
-    def _setObject(self,id,object,roles=None,user=None, set_owner=1):
+    def _setObject(self, id, object, roles=None, user=None, set_owner=1):
         v=self._checkId(id)
         if v is not None: id=v
         try:    t=object.meta_type
@@ -306,13 +323,13 @@ class ObjectManager(
             except:
                 LOG('Zope',ERROR,'manage_beforeDelete() threw',
                     error=sys.exc_info())
-                pass
+                # In debug mode when non-Manager, let exceptions propagate.
+                if getConfiguration().debug_mode:
+                    if not getSecurityManager().getUser().has_role('Manager'):
+                        raise
             if s is None: object._p_deactivate()
 
     def _delObject(self, id, dp=1):
-        # dp is here for backwards compatibility as it once
-        # allowed to override the use of the delete protocol.
-        # See http://collector.zope.org/Zope/1377 
         object=self._getOb(id)
         try:
             object.manage_beforeDelete(object, self)
@@ -321,9 +338,12 @@ class ObjectManager(
         except ConflictError:
             raise
         except:
-            LOG('Zope',ERROR,'manage_beforeDelete() threw',
+            LOG('Zope', ERROR, '_delObject() threw',
                 error=sys.exc_info())
-            pass
+            # In debug mode when non-Manager, let exceptions propagate.
+            if getConfiguration().debug_mode:
+                if not getSecurityManager().getUser().has_role('Manager'):
+                    raise
         self._objects=tuple(filter(lambda i,n=id: i['id']!=n, self._objects))
         self._delOb(id)
 
@@ -349,14 +369,12 @@ class ObjectManager(
             return set
         return [ o['id']  for o in self._objects ]
 
-
     def objectValues(self, spec=None):
         # Returns a list of actual subobjects of the current object.
         # If 'spec' is specified, returns only objects whose meta_type
         # match 'spec'.
         return [ self._getOb(id) for id in self.objectIds(spec) ]
 
-
     def objectItems(self, spec=None):
         # Returns a list of (id, subobject) tuples of the current object.
         # If 'spec' is specified, returns only objects whose meta_type match
@@ -367,7 +385,7 @@ class ObjectManager(
         # Return a tuple of mappings containing subobject meta-data
         return tuple(map(lambda dict: dict.copy(), self._objects))
 
-    def objectIds_d(self,t=None):
+    def objectIds_d(self, t=None):
         if hasattr(self, '_reserved_names'): n=self._reserved_names
         else: n=()
         if not n: return self.objectIds(t)
@@ -377,17 +395,17 @@ class ObjectManager(
             if id not in n: a(id)
         return r
 
-    def objectValues_d(self,t=None):
+    def objectValues_d(self, t=None):
         return map(self._getOb, self.objectIds_d(t))
 
-    def objectItems_d(self,t=None):
+    def objectItems_d(self, t=None):
         r=[]
         a=r.append
         g=self._getOb
         for id in self.objectIds_d(t): a((id, g(id)))
         return r
 
-    def objectMap_d(self,t=None):
+    def objectMap_d(self, t=None):
         if hasattr(self, '_reserved_names'): n=self._reserved_names
         else: n=()
         if not n: return self._objects
@@ -397,7 +415,7 @@ class ObjectManager(
             if d['id'] not in n: a(d.copy())
         return r
 
-    def superValues(self,t):
+    def superValues(self, t):
         # Return all of the objects of a given type located in
         # this object and containing objects.
         if type(t)==type('s'): t=(t,)
@@ -569,10 +587,23 @@ class ObjectManager(
         ob=self._getOb(id)
         ob.manage_changeOwnershipType(explicit=0)
 
+    def list_imports(self):
+        listing = []
+        cfg = getConfiguration()
+        paths = [cfg.zopehome]
+        if not cfg.instancehome in paths:
+            paths.append(cfg.instancehome)
+        for impath in paths:
+            directory = os.path.join(impath, 'import')
+            listing += [f for f in os.listdir(directory) 
+                        if f.endswith('.zexp') or f.endswith('.xml')]
+        return listing
+
     # FTP support methods
 
     def manage_FTPlist(self, REQUEST):
-        "Directory listing for FTP"
+        """Directory listing for FTP.
+        """
         out=()
 
         # check to see if we are being acquiring or not
@@ -605,7 +636,7 @@ class ObjectManager(
 
         globbing = REQUEST.environ.get('GLOBBING','')
         if globbing :
-            files = filter(lambda x,g=globbing: fnmatch.fnmatch(x[0],g) , files)
+            files = filter(lambda x,g=globbing: fnmatch.fnmatch(x[0],g), files)
 
         files.sort()
 
@@ -628,20 +659,30 @@ class ObjectManager(
                 out=out+((k,stat),)
         return marshal.dumps(out)
 
+    def manage_hasId(self, REQUEST):
+        """ check if the folder has an object with REQUEST['id'] """
+
+        if not REQUEST['id'] in self.objectIds():
+            raise KeyError(REQUEST['id'])
+
     def manage_FTPstat(self,REQUEST):
-        "Psuedo stat used for FTP listings"
+        """Psuedo stat, used by FTP for directory listings.
+        """
         mode=0040000
         from AccessControl.User import nobody
         # check to see if we are acquiring our objectValues or not
         if not (len(REQUEST.PARENTS) > 1 and
                 self.objectValues() == REQUEST.PARENTS[1].objectValues()):
             try:
-                if getSecurityManager().validateValue(self.manage_FTPlist):
+                if getSecurityManager().validate(
+                    None, self, 'manage_FTPlist', self.manage_FTPlist
+                    ):
                     mode=mode | 0770
             except: pass
+
             if nobody.allowed(
-                        self.manage_FTPlist,
-                        self.manage_FTPlist.__roles__):
+                self,
+                getRoles(self, 'manage_FTPlist', self.manage_FTPlist, ())):
                 mode=mode | 0007
         mtime=self.bobobase_modification_time().timeTime()
         # get owner and group
@@ -662,9 +703,10 @@ class ObjectManager(
                 return NullResource(self, key, request).__of__(self)
         raise KeyError, key
 
+
 def findChildren(obj,dirname=''):
     """ recursive walk through the object hierarchy to
-    find all childs of an object (ajung)
+    find all children of an object (ajung)
     """
 
     lst =[]
@@ -676,7 +718,9 @@ def findChildren(obj,dirname=''):
 
     return lst
 
+
 class IFAwareObjectManager:
+
     def all_meta_types(self, interfaces=None):
 
         if interfaces is None:
