@@ -7,36 +7,38 @@
 # THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
 # WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 # WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
-# FOR A PARTICULAR PURPOSE
+# FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
+"""Deprecated text index. Please use ZCTextIndex instead.
 
-"""Text Index
-
+$Id: TextIndex.py 31005 2005-07-05 13:38:18Z yuppie $
 """
-__version__ = '$Revision: 1.36 $'[11:-2]
 
+import operator, warnings
+import re
+from cgi import escape
+from types import *
 
-import  re
-import operator,warnings
-from Globals import Persistent,DTMLFile
+from Globals import Persistent, DTMLFile
 from zLOG import LOG, ERROR
 from Acquisition import Implicit
-from Products.PluginIndexes.common.ResultList import ResultList
-from Products.PluginIndexes import PluggableIndex
-from Products.PluginIndexes.common.util import parseIndexRequest
-
 from OFS.SimpleItem import SimpleItem
 from BTrees.IOBTree import IOBTree
-from BTrees.OIBTree import OIBTree
-from BTrees.IIBTree import IIBTree, IIBucket, IISet, IITreeSet
+from BTrees.IIBTree import IIBTree, IIBucket, IISet
 from BTrees.IIBTree import difference, weightedIntersection
+from BTrees.OIBTree import OIBTree
+from zope.interface import implements
+
+from Products.PluginIndexes import PluggableIndex
 from Products.PluginIndexes.common import safe_callable
+from Products.PluginIndexes.common.ResultList import ResultList
+from Products.PluginIndexes.common.util import parseIndexRequest
+from Products.PluginIndexes.interfaces import IPluggableIndex
+from Products.PluginIndexes.interfaces import ITextIndex
 
 from Lexicon import Lexicon
 
-from types import *
-from cgi import escape
 
 class Op:
     def __init__(self, name):
@@ -54,7 +56,9 @@ operator_dict = {'andnot': AndNot, 'and': And, 'or': Or,
                  '...': Near, 'near': Near,
                  AndNot: AndNot, And: And, Or: Or, Near: Near}
 
+
 class TextIndex(Persistent, Implicit, SimpleItem):
+
     """Full-text index.
 
     There is a ZCatalog UML model that sheds some light on what is
@@ -64,16 +68,17 @@ class TextIndex(Persistent, Implicit, SimpleItem):
       {'bob' : {1 : 5, 2 : 3, 42 : 9}}
       {'uncle' : {1 : 1}}
 
-
     The '_unindex' attribute is a mapping from document id to word
     ids.  This mapping allows the catalog to unindex an object:
 
       {42 : ('bob', 'is', 'your', 'uncle')
 
     This isn't exactly how things are represented in memory, many
-    optimizations happen along the way."""
+    optimizations happen along the way.
+    """
 
     __implements__ = (PluggableIndex.PluggableIndexInterface,)
+    implements(ITextIndex, IPluggableIndex)
 
     meta_type='TextIndex'
 
@@ -114,11 +119,9 @@ class TextIndex(Persistent, Implicit, SimpleItem):
         self.call_methods   = call_methods
         self.catalog        = caller
 
-
         # Default text index operator (should be visible to ZMI)
         self.useOperator  = 'or'
 
-
         if extra:   self.vocabulary_id = extra.vocabulary
         else:       self.vocabulary_id = "Vocabulary"
 
@@ -132,11 +135,12 @@ class TextIndex(Persistent, Implicit, SimpleItem):
             self._lexicon = lexicon
             self.vocabulary_id = '__userdefined__'
 
-
-    def getId(self): return self.id
+    def getId(self):
+        return self.id
 
     def getLexicon(self, vocab_id=None):
-        """Return the Lexicon in use. Removed lots of stinking code"""
+        """Get the Lexicon in use.
+        """
 
         if self._lexicon is None:
             ## if no lexicon is provided, create a default one
@@ -152,12 +156,9 @@ class TextIndex(Persistent, Implicit, SimpleItem):
 
         return self._lexicon
 
-
-
     def __nonzero__(self):
         return not not self._unindex
 
-
     def clear(self):
         """Reinitialize the text index."""
         self._index   = IOBTree()
@@ -186,7 +187,6 @@ class TextIndex(Persistent, Implicit, SimpleItem):
                 scores=IIBTree(scores)
             return scores
 
-
         convert(_index, self._index, threshold, convertScores)
 
         _unindex=self._unindex
@@ -205,7 +205,6 @@ class TextIndex(Persistent, Implicit, SimpleItem):
 
         return histogram
 
-
     def getEntryForObject(self, rid, default=None):
         """Get all information contained for a specific object.
 
@@ -219,7 +218,6 @@ class TextIndex(Persistent, Implicit, SimpleItem):
             return tuple(map(self.getLexicon().getWord,
                              results))
 
-
     def insertForwardIndexEntry(self, entry, documentId, score=1):
         """Uses the information provided to update the indexes.
 
@@ -303,7 +301,6 @@ class TextIndex(Persistent, Implicit, SimpleItem):
         except (AttributeError, TypeError):
             encoding = 'latin1'
 
-
         lexicon = self.getLexicon()
 
         splitter = lexicon.Splitter
@@ -444,7 +441,6 @@ class TextIndex(Persistent, Implicit, SimpleItem):
 
             return r
 
-
     def _apply_index(self, request, cid=''):
         """ Apply the index to query parameters given in the argument,
         request
@@ -500,7 +496,6 @@ class TextIndex(Persistent, Implicit, SimpleItem):
 
         return (IIBucket(), (self.id,))
 
-
     def positions(self, docid, words,
                   # This was never tested: obj
                   ):
@@ -513,14 +508,12 @@ class TextIndex(Persistent, Implicit, SimpleItem):
         # The code below here is broken and requires an API change to fix
         # it. Waaaaa.
 
-
         if self._schema is None:
             f = getattr
         else:
             f = operator.__getitem__
             id = self._schema[self.id]
 
-
         if self.call_methods:
             doc = str(f(obj, self.id)())
         else:
@@ -531,8 +524,6 @@ class TextIndex(Persistent, Implicit, SimpleItem):
             r = r+self.getLexicon().Splitter(doc).indexes(word)
         return r
 
-
-
     def query(self, s, default_operator=Or):
         """ Evaluate a query string.
 
@@ -566,7 +557,6 @@ class TextIndex(Persistent, Implicit, SimpleItem):
         # evalute the final 'expression'
         return self.evaluate(q)
 
-
     def get_operands(self, q, i):
         """Evaluate and return the left and right operands for an operator"""
         try:
@@ -593,8 +583,6 @@ class TextIndex(Persistent, Implicit, SimpleItem):
 
         return (left, right)
 
-
-
     def evaluate(self, query):
         """Evaluate a parsed query"""
         # Strip off meaningless layers
@@ -649,17 +637,14 @@ class TextIndex(Persistent, Implicit, SimpleItem):
         """ return name of indexed attributes """
         return (self.id, )
 
-
     def numObjects(self):
         """ return number of index objects """
         return len(self._index)
 
-
     def manage_setPreferences(self,vocabulary,
                                REQUEST=None,RESPONSE=None,URL2=None):
         """ preferences of TextIndex """
 
-
         if self.vocabulary_id != vocabulary:
             self.clear()
             self.vocabulary_id    = vocabulary
@@ -667,10 +652,10 @@ class TextIndex(Persistent, Implicit, SimpleItem):
         if RESPONSE:
             RESPONSE.redirect(URL2 + '/manage_main?manage_tabs_message=Preferences%20saved')
 
-
     manage_workspace  = DTMLFile("dtml/manageTextIndex",globals())
     manage_vocabulary = DTMLFile("dtml/manageVocabulary",globals())
 
+
 def parse(s):
     """Parse parentheses and quotes"""
     l = []
@@ -713,7 +698,6 @@ def parse2(q, default_operator, operator_dict=operator_dict):
 
     return q
 
-
 def parens(s, parens_re=re.compile('[()]').search):
     mo = parens_re(s)
     if mo is None:
@@ -737,7 +721,6 @@ def parens(s, parens_re=re.compile('[()]').search):
 
     raise QueryError, "Mismatched parentheses"
 
-
 def quotes(s):
 
     if '"' not in s:
@@ -766,7 +749,6 @@ def quotes(s):
 
     return filter(None, splitted)
 
-
 manage_addTextIndexForm = DTMLFile('dtml/addTextIndex', globals())
 
 def manage_addTextIndex(self, id, extra=None, REQUEST=None, RESPONSE=None, URL3=None):
