@@ -7,33 +7,43 @@
 # THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
 # WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 # WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
-# FOR A PARTICULAR PURPOSE
+# FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
+"""Topic index.
 
-__version__ = '$Id: TopicIndex.py,v 1.13.2.3 2003/12/31 22:39:30 poster Exp $'
+$Id: TopicIndex.py 31005 2005-07-05 13:38:18Z yuppie $
+"""
+
+from logging import getLogger
 
 from Globals import Persistent, DTMLFile
 from OFS.SimpleItem import SimpleItem
-from zLOG import ERROR, LOG
 from BTrees.OOBTree import OOBTree
 from BTrees.IIBTree import IITreeSet,intersection,union
+from zope.interface import implements
 
-import FilteredSet
 from Products.PluginIndexes import PluggableIndex
 from Products.PluginIndexes.common.util import parseIndexRequest
+from Products.PluginIndexes.interfaces import IPluggableIndex
+from Products.PluginIndexes.interfaces import ITopicIndex
+
+import FilteredSet
 
 _marker = []
+LOG = getLogger('Zope.TopicIndex')
+
 
 class TopicIndex(Persistent, SimpleItem):
 
-    """ A TopicIndex maintains a set of FilteredSet objects.
-        Every FilteredSet object consists of an expression and
-        and IISet with all Ids of indexed objects that eval with
-        this expression to 1.
+    """A TopicIndex maintains a set of FilteredSet objects.
+
+    Every FilteredSet object consists of an expression and and IISet with all
+    Ids of indexed objects that eval with this expression to 1.
     """
 
     __implements__ = (PluggableIndex.PluggableIndexInterface,)
+    implements(ITopicIndex, IPluggableIndex)
 
     meta_type="TopicIndex"
     query_options = ('query','operator')
@@ -50,7 +60,8 @@ class TopicIndex(Persistent, SimpleItem):
         self.operators = ('or','and')
         self.defaultOperator = 'or'
 
-    def getId(self): return self.id
+    def getId(self):
+        return self.id
 
     def clear(self):
         for fs in self.filteredSets.values():
@@ -69,9 +80,8 @@ class TopicIndex(Persistent, SimpleItem):
             try:
                 fs.unindex_object(docid)
             except KeyError:
-                LOG(self.__class__.__name__, ERROR,
-                    'Attempt to unindex document'
-                    ' with id %s failed' % docid)
+                LOG.error('Attempt to unindex document'
+                          ' with id %s failed' % docid)
         return 1
 
     def numObjects(self):
@@ -110,25 +120,27 @@ class TopicIndex(Persistent, SimpleItem):
 
     def getEntryForObject(self,docid, default=_marker):
         """ Takes a document ID and returns all the information we have
-            on that specific object. 
+            on that specific object.
         """
         return self.filteredSets.keys()
 
     def addFilteredSet(self, filter_id, typeFilteredSet, expr):
-
+        # Add a FilteredSet object.
         if self.filteredSets.has_key(filter_id):
             raise KeyError,\
                 'A FilteredSet with this name already exists: %s' % filter_id
         self.filteredSets[filter_id] = \
             FilteredSet.factory(filter_id, typeFilteredSet, expr)
 
-    def delFilteredSet(self,filter_id):
+    def delFilteredSet(self, filter_id):
+        # Delete the FilteredSet object specified by 'filter_id'.
         if not self.filteredSets.has_key(filter_id):
             raise KeyError,\
                 'no such FilteredSet:  %s' % filter_id
         del self.filteredSets[filter_id]
 
-    def clearFilteredSet(self,filter_id):
+    def clearFilteredSet(self, filter_id):
+        # Clear the FilteredSet object specified by 'filter_id'.
         if not self.filteredSets.has_key(filter_id):
             raise KeyError,\
                 'no such FilteredSet:  %s' % filter_id
@@ -183,7 +195,6 @@ class TopicIndex(Persistent, SimpleItem):
             RESPONSE.redirect(URL1+'/manage_workspace?'
              'manage_tabs_message=FilteredSet(s)%20cleared')
 
-
     index_html      = DTMLFile('dtml/index', globals())
     manage_workspace = DTMLFile('dtml/manageTopicIndex',globals())
     editFilteredSet = DTMLFile('dtml/editFilteredSet',globals())
