@@ -7,13 +7,15 @@ Also see http://zope.org/Collectors/Zope/809
 
 Note: Tests require Zope >= 2.7
 
-$Id: testVirtualHostMonster.py,v 1.1.2.4 2004/11/26 09:57:36 tino Exp $
+$Id: testVirtualHostMonster.py 29694 2005-03-28 16:34:11Z tim_one $
 """
 
 from Testing.makerequest import makerequest
 
-import Zope
-Zope.startup()
+import Zope2
+Zope2.startup()
+
+import transaction
 
 import unittest
 
@@ -21,8 +23,8 @@ import unittest
 class VHMRegressions(unittest.TestCase):
 
     def setUp(self):
-        get_transaction().begin()
-        self.app = makerequest(Zope.app())
+        transaction.begin()
+        self.app = makerequest(Zope2.app())
         try:
             #self.app.manage_addProduct['SiteAccess'].manage_addVirtualHostMonster('VHM')
             # now we have a VHM as virtual_hosting per default
@@ -34,7 +36,7 @@ class VHMRegressions(unittest.TestCase):
             self.tearDown()
 
     def tearDown(self):
-        get_transaction().abort()
+        transaction.abort()
         self.app._p_jar.close()
 
     def testAbsoluteUrl(self):
