@@ -26,11 +26,8 @@ import time
 import Globals
 from Globals import DTMLFile
 
-try: from cPickle import Pickler
-except: from pickle import Pickler
-
-try: from cStringIO import dumps
-except: from pickle import dumps
+try: from cPickle import Pickler, HIGHEST_PROTOCOL
+except: from pickle import Pickler, HIGHEST_PROTOCOL
 
 _marker = []  # Create a new marker object.
 
@@ -52,7 +49,17 @@ class CacheEntry:
             # us from caching something that might result in memory
             # leaks.  It's also convenient for determining the
             # approximate memory usage of the cache entry.
-            self.size = len(dumps(index)) + len(dumps(data))
+            # DM 2004-11-29: this code causes excessive time.
+            #   Note also that it does not prevent us from
+            #   caching objects with references to persistent objects
+            #   When we do, nasty persistency errors are likely
+            #   to occur ("shouldn't load data while connection is closed").
+            #self.size = len(dumps(index)) + len(dumps(data))
+            sizer = _ByteCounter()
+            pickler = Pickler(sizer, HIGHEST_PROTOCOL)
+            pickler.dump(index)
+            pickler.dump(data)
+            self.size = sizer.getCount()
         except:
             raise CacheException('The data for the cache is not pickleable.')
         self.created = time.time()
@@ -346,7 +353,7 @@ class RAMCacheManager (CacheManager, SimpleItem):
                                      'manage_stats',
                                      'getCacheReport',
                                      'sort_link',)),
-        ('Change cache managers', ('manage_editProps',), ('Manager',)),
+        ('Change cache managers', ('manage_editProps','manage_invalidate'), ('Manager',)),
         )
 
     manage_options = (
@@ -451,9 +458,33 @@ class RAMCacheManager (CacheManager, SimpleItem):
         url = url + '&sort_reverse=' + (newsr and '1' or '0')
         return '<a href="%s">%s</a>' % (escape(url, 1), escape(name))
 
+    def manage_invalidate(self, paths, REQUEST=None):
+        """ ZMI helper to invalidate an entry """
+        for path in paths:
+            try:
+                ob = self.unrestrictedTraverse(path)
+            except (AttributeError, KeyError):
+                pass
+
+            ob.ZCacheable_invalidate()
+
+        if REQUEST is not None:
+            msg = 'Cache entries invalidated'
+            return self.manage_stats(manage_tabs_message=msg)
+
 Globals.default__class_init__(RAMCacheManager)
 
 
+class _ByteCounter:
+    '''auxiliary file like class which just counts the bytes written.'''
+    _count = 0
+
+    def write(self, bytes):
+        self._count += len(bytes)
+
+    def getCount(self):
+        return self._count
+
 manage_addRAMCacheManagerForm = DTMLFile('dtml/addRCM', globals())
 
 def manage_addRAMCacheManager(self, id, REQUEST=None):
