@@ -12,8 +12,8 @@
 ##############################################################################
 '''CGI Response Output formatter
 
-$Id: HTTPResponse.py,v 1.75.2.6 2004/04/26 10:11:23 shh Exp $'''
-__version__ = '$Revision: 1.75.2.6 $'[11:-2]
+$Id: HTTPResponse.py 39027 2005-10-09 23:25:39Z chrisw $'''
+__version__ = '$Revision: 1.81 $'[11:-2]
 
 import types, os, sys, re
 import zlib, struct
@@ -26,6 +26,8 @@ from cgi import escape
 
 nl2sp = maketrans('\n',' ')
 
+# This may get overwritten during configuration
+default_encoding = 'iso-8859-15'
 
 # Enable APPEND_TRACEBACKS to make Zope append tracebacks like it used to,
 # but a better solution is to make standard_error_message display error_tb.
@@ -146,6 +148,7 @@ class HTTPResponse(BaseResponse):
     realm = 'Zope'
     _error_format = 'text/html'
     _locked_status = 0
+    _locked_body = 0
 
     # Indicate if setBody should content-compress output.
     # 0 - no compression
@@ -199,7 +202,7 @@ class HTTPResponse(BaseResponse):
         """Returns true if this request requested a server shutdown."""
         return self._shutdown_flag is not None
 
-    def setStatus(self, status, reason=None):
+    def setStatus(self, status, reason=None, lock=None):
         '''\
         Sets the HTTP status code of the response; the argument may
         either be an integer or a string from { OK, Created, Accepted,
@@ -234,6 +237,9 @@ class HTTPResponse(BaseResponse):
                 reason = 'Unknown'
         self.setHeader('Status', "%d %s" % (status,str(reason)))
         self.errmsg = reason
+        # lock the status if we're told to
+        if lock:
+             self._locked_status = 1
 
     def setHeader(self, name, value, literal=0):
         '''\
@@ -268,7 +274,8 @@ class HTTPResponse(BaseResponse):
                 latin1_alias_match=re.compile(
                 r'text/html(\s*;\s*charset=((latin)|(latin[-_]?1)|'
                 r'(cp1252)|(cp819)|(csISOLatin1)|(IBM819)|(iso-ir-100)|'
-                r'(iso[-_]8859[-_]1(:1987)?)))?$',re.I).match
+                r'(iso[-_]8859[-_]1(:1987)?)))?$',re.I).match,
+                lock=None
                 ):
         '''\
         Set the body of the response
@@ -285,11 +292,17 @@ class HTTPResponse(BaseResponse):
         If is_error is true then the HTML will be formatted as a Zope error
         message instead of a generic HTML page.
         '''
+        # allow locking of the body in the same way as the status
+        if self._locked_body:
+            return
+        elif lock:
+            self._locked_body = 1
+            
         if not body:
             return self
 
         if isinstance(body, tuple) and len(body) == 2:
-            title,body = body
+            title, body = body
 
         if not isinstance(body, str):
             if hasattr(body,'asHTML'):
@@ -340,7 +353,7 @@ class HTTPResponse(BaseResponse):
         self.setHeader('content-length', len(self.body))
         self.insertBase()
         if self.use_HTTP_content_compression and \
-            not self.headers.get('content-encoding',None):
+            self.headers.get('content-encoding', 'gzip') == 'gzip':
             # use HTTP content encoding to compress body contents unless
             # this response already has another type of content encoding
             if content_type.split('/')[0] not in uncompressableMimeMajorTypes:
@@ -422,7 +435,7 @@ class HTTPResponse(BaseResponse):
         return self.use_HTTP_content_compression
 
     def _encode_unicode(self,body,
-                        charset_re=re.compile(r'text/[0-9a-z]+\s*;\s*' +
+                        charset_re=re.compile(r'(?:application|text)/[-+0-9a-z]+\s*;\s*' +
                                               r'charset=([-_0-9a-z]+' +
                                               r')(?:(?:\s*;)|\Z)',
                                               re.IGNORECASE)):
@@ -433,7 +446,7 @@ class HTTPResponse(BaseResponse):
                 encoding = match.group(1)
                 return body.encode(encoding)
         # Use the default character encoding
-        return body.encode('latin1','replace')
+        return body.encode(default_encoding,'replace')
 
     def setBase(self,base):
         """Set the base URL for the returned document.
@@ -533,7 +546,7 @@ class HTTPResponse(BaseResponse):
         Sets an HTTP return header "name" with value "value",
         appending it following a comma if there was a previous value
         set for the header. '''
-        name = str(name)
+        name = str(name).lower()
         value = str(value)
 
         headers = self.headers
