@@ -13,10 +13,10 @@
 
 """WebDAV xml request objects.
 
-$Id: davcmds.py,v 1.20.66.2 2003/11/17 22:34:22 tseaver Exp $
+$Id: davcmds.py 37530 2005-07-28 10:14:13Z andreasjung $
 """
 
-import sys, os
+import sys
 from common import absattr, aq_base, urlfix, urlbase
 from OFS.PropertySheets import DAVProperties
 from LockItem import LockItem
@@ -29,6 +29,8 @@ from AccessControl import getSecurityManager
 from zExceptions import BadRequest, Forbidden
 from common import isDavCollection
 from common import PreconditionFailed
+from ZConfig.url import urljoin
+import transaction
 
 def safe_quote(url, mark=r'%'):
     if url.find(mark) > -1:
@@ -161,7 +163,7 @@ class PropFind:
                     if dflag:
                         ob._p_deactivate()
                 elif hasattr(ob, '__dav_resource__'):
-                    uri=os.path.join(url, absattr(ob.id))
+                    uri=urljoin(url, absattr(ob.id))
                     depth=depth=='infinity' and depth or 0
                     self.apply(ob, uri, depth, result, top=0)
                     if dflag:
@@ -246,7 +248,6 @@ class PropPatch:
                 if propset is None:
                     propsets.manage_addPropertySheet('', ns)
                     propset=propsets.get(ns)
-                propdict=propset._propdict()
                 if propset.hasProperty(name):
                     try:
                         propset._updateProperty(name, val, meta=md)
@@ -272,8 +273,6 @@ class PropPatch:
                     except:
                         errors.append('%s cannot be deleted.' % name)
                         status='409 Conflict'
-            if result != '200 OK':
-                abort = 1
             result.write('<d:propstat xmlns:n="%s">\n' \
                          '  <d:prop>\n' \
                          '  <n:%s/>\n' \
@@ -291,7 +290,7 @@ class PropPatch:
             return result
         # This is lame, but I cant find a way to keep ZPublisher
         # from sticking a traceback into my xml response :(
-        get_transaction().abort()
+        transaction.abort()
         result=result.replace( '200 OK', '424 Failed Dependency')
         return result
 
@@ -360,7 +359,7 @@ class Lock:
             if token is None:
                 token = lock.getLockToken()
 
-        except ValueError, valerrors:
+        except ValueError:
             errmsg = "412 Precondition Failed"
         except:
             errmsg = "403 Forbidden"
@@ -404,7 +403,7 @@ class Lock:
         if depth == 'infinity' and iscol:
             for ob in obj.objectValues():
                 if hasattr(obj, '__dav_resource__'):
-                    uri = os.path.join(url, absattr(ob.id))
+                    uri = urljoin(url, absattr(ob.id))
                     self.apply(ob, creator, depth, token, result,
                                uri, top=0)
         if not top:
@@ -413,7 +412,7 @@ class Lock:
             # One or more subitems probably failed, so close the multistatus
             # element and clear out all succesful locks
             result.write('</d:multistatus>')
-            get_transaction().abort() # This *SHOULD* clear all succesful locks
+            transaction.abort() # This *SHOULD* clear all succesful locks
         return token, result.getvalue()
 
 
@@ -467,7 +466,7 @@ class Unlock:
             for ob in obj.objectValues():
                 if hasattr(ob, '__dav_resource__') and \
                    WriteLockInterface.isImplementedBy(ob):
-                    uri = os.path.join(url, absattr(ob.id))
+                    uri = urljoin(url, absattr(ob.id))
                     self.apply(ob, token, uri, result, top=0)
         if not top:
             return result
@@ -475,7 +474,7 @@ class Unlock:
             # One or more subitems probably failed, so close the multistatus
             # element and clear out all succesful unlocks
             result.write('</d:multistatus>')
-            get_transaction().abort()
+            transaction.abort()
         return result.getvalue()
 
 
@@ -521,7 +520,7 @@ class DeleteCollection:
             for ob in obj.objectValues():
                 dflag = hasattr(ob,'_p_changed') and (ob._p_changed == None)
                 if hasattr(ob, '__dav_resource__'):
-                    uri = os.path.join(url, absattr(ob.id))
+                    uri = urljoin(url, absattr(ob.id))
                     self.apply(ob, token, user, uri, result, top=0)
                     if dflag:
                         ob._p_deactivate()
